import java.awt.Color;
import java.awt.GridBagLayout;
import java.awt.GridBagConstraints;

import quicktime.QTSession;
import quicktime.QTException;

import com.apple.mrj.MRJApplicationUtils;
import com.apple.mrj.MRJQuitHandler;

import quicktime.app.display.FullScreenWindow;
import quicktime.std.movies.FullScreen;

/**
 * QTZoo Module 9 - Using Full Screen Mode
 * This application requires QuickTime for Java
 *
 * @author Levi Brown
 * @author Michael Hopkins
 * @author Apple Computer, Inc.
 * @version 9.0 4/10/2000
 * 
 * Copyright: 	 Copyright 1999 Apple Computer, Inc. All rights reserved.
 *	
 * Disclaimer:	IMPORTANT:  This Apple software is supplied to you by Apple Computer, Inc.
 *				("Apple") in consideration of your agreement to the following terms, and your
 *				use, installation, modification or redistribution of this Apple software
 *				constitutes acceptance of these terms.  If you do not agree with these terms,
 *				please do not use, install, modify or redistribute this Apple software.
 *
 *				In consideration of your agreement to abide by the following terms, and subject
 *				to these terms, Apple grants you a personal, non-exclusive license, under Apples
 *				copyrights in this original Apple software (the "Apple Software"), to use,
 *				reproduce, modify and redistribute the Apple Software, with or without
 *				modifications, in source and/or binary forms; provided that if you redistribute
 *				the Apple Software in its entirety and without modifications, you must retain
 *				this notice and the following text and disclaimers in all such redistributions of
 *				the Apple Software.  Neither the name, trademarks, service marks or logos of
 *				Apple Computer, Inc. may be used to endorse or promote products derived from the
 *				Apple Software without specific prior written permission from Apple.  Except as
 *				expressly stated in this notice, no other rights or licenses, express or implied,
 *				are granted by Apple herein, including but not limited to any patent rights that
 *				may be infringed by your derivative works or by other works in which the Apple
 *				Software may be incorporated.
 *
 *				The Apple Software is provided by Apple on an "AS IS" basis.  APPLE MAKES NO
 *				WARRANTIES, EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION THE IMPLIED
 *				WARRANTIES OF NON-INFRINGEMENT, MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 *				PURPOSE, REGARDING THE APPLE SOFTWARE OR ITS USE AND OPERATION ALONE OR IN
 *				COMBINATION WITH YOUR PRODUCTS.
 *
 *				IN NO EVENT SHALL APPLE BE LIABLE FOR ANY SPECIAL, INDIRECT, INCIDENTAL OR
 *				CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
 *				GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 *				ARISING IN ANY WAY OUT OF THE USE, REPRODUCTION, MODIFICATION AND/OR DISTRIBUTION
 *				OF THE APPLE SOFTWARE, HOWEVER CAUSED AND WHETHER UNDER THEORY OF CONTRACT, TORT
 *				(INCLUDING NEGLIGENCE), STRICT LIABILITY OR OTHERWISE, EVEN IF APPLE HAS BEEN
 *				ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

public class Zoo9 implements MRJQuitHandler
{
	/**
	 *  Zoo constructor
	 */
	public Zoo9() 
	{
		MRJApplicationUtils.registerQuitHandler(this);			// register handler for command-Q
		try
		{	
			window = new FullScreenWindow(new FullScreen());	// create a new fullscreen window
			window.setBackground (Color.black);					// color window black
			window.setLayout(new GridBagLayout());
			gbc = new GridBagConstraints();
			gbc.gridx = 1;
			gbc.gridy = 1;
			gbc.gridwidth = 1;
			gbc.anchor = GridBagConstraints.CENTER;
			gbc.fill = GridBagConstraints.NONE;

			window.show();
			run();
		}
		catch (QTException exc)
		{
			exc.printStackTrace();
		}
	}
	
	/**
	 * Main body of class. Creates main window, and displays it
	 */
	public void run()
	{
		mainFrame = new MainFrame(window);
		mainFrame.setVisible(true);
		((GridBagLayout)window.getLayout()).setConstraints(mainFrame, gbc);
		window.add(mainFrame);
		mainFrame.invalidate();
		window.validate();
	}
	
	/**
	 * Handles quitting the application.
	 * This routine gets called by the MRJToolkit when the
	 * application is about to quit.
	 */
	public void handleQuit()
	{
		mainFrame.handleQuit();
	}

	static public void main(String[] args) 
	{
		try
		{
			QTSession.open();			// Initialize QuickTime 
			new Zoo9();	
		}
		catch (Exception e) 
		{
			e.printStackTrace();
			QTSession.close();			// Shut down QuickTime and dispose of native context
		}
	}
	
	protected MainFrame mainFrame;
	
	protected FullScreenWindow window;
	protected GridBagConstraints gbc;
}
